# JMTrucoCmd: Juego de Truco

![Mora Truco Logo](https://lmdiario.com.ar/download/multimedia.normal.914acb1e58d4fa82.547275636f2d4361727461735f6e6f726d616c2e6a7067.jpg)

JMTrucoCmd es un framework para crear y jugar partidas de truco argentino. Este proyecto proporciona una base sólida para poder divertirse y matar el tiempo.

## Instalación
```bash
pip install JMTrucoCmd 
```

## Uso
```python
from JMTrucoCmd import Game
game = Game()
game.start()
```

## Autor
Joaquin Morais

## Licencia
Copyright (c) 2024 Joaquin Morais